<?xml version="1.0" encoding="UTF-8"?>
<!-- 
    Copyright (c) 2005, 2007 IBM Corporation and others.
    All rights reserved. This program and the accompanying materials
    are made available under the terms of the Eclipse Public License v1.0
    which accompanies this distribution, and is available at
    http://www.eclipse.org/legal/epl-v10.html
    Contributors:
    IBM Corporation - initial implementation
-->

<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">

<xsl:output method="html" version="1.0" encoding="UTF-8" 
	doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" 
	doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" 
	indent="yes"/>
	
	<xsl:include href="activity_helper.xsl"/>
	<xsl:include href="property.xsl"/>


	<xsl:template match="/Element">
		<xsl:variable name="elementType" select="@Type"/>
		<xsl:variable name="elementTypeName" select="@TypeName"/>
		<xsl:variable name="elementName" select="@Name"/>
		<xsl:variable name="elementPresentationName" select="@DisplayName"/>
		<xsl:variable name="backPath" select="@BackPath"/>
		<xsl:variable name="imagePath" select="concat($backPath, 'images/')"/>
		<xsl:variable name="shapeImage" select="concat($backPath,@ShapeiconUrl)"/>
		<xsl:variable name="presentation" select="reference[@name='presentation']"/>
		<xsl:variable name="contentDescription" select="$presentation/Element"/>
		<xsl:variable name="copyright" select="copyright"/>
		<xsl:variable name="showTreeBrowser" select="@showTreeBrowser"/>
		<xsl:variable name="responsibleRole" select="reference[@name='responsibleRole']/Element[@Type='Role']"/>
		<xsl:variable name="queryString" select="@queryString"/>
		<xsl:variable name="relProcessPath" select="@relProcessPath"/>		
		<xsl:variable name="showFullMethodContent" select="@ShowFullMethodContent"/>
		<html>
			<xsl:attribute name="lang"><xsl:value-of select="@lang"/></xsl:attribute>
			<xsl:attribute name="xml:lang"><xsl:value-of select="@lang"/></xsl:attribute>
			<head>
				<title>
					<xsl:value-of select="$elementTypeName"/>: <xsl:value-of select="$elementPresentationName"/>
				</title>
				<xsl:call-template name="umaMetaTags">
					<xsl:with-param name="elementType" select="$elementType"/>
					<xsl:with-param name="elementName" select="$elementName"/>
					<xsl:with-param name="elementPresentationName" select="$elementPresentationName"/>
				</xsl:call-template>
				<meta name="element_type">
					<xsl:call-template name="mapping">
						<xsl:with-param name="elementType" select="$elementType"/>
					</xsl:call-template>
				</meta>
				<meta name="filetype" content="description"/>
				<meta name="role">
					<xsl:choose>  
						<xsl:when test="$responsibleRole/@DisplayName!=''">
							<xsl:attribute name="content"><xsl:value-of select="$responsibleRole/@DisplayName"/></xsl:attribute>
						</xsl:when>  
						<xsl:otherwise>
							<xsl:attribute name="content">none</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
				</meta>
				<link rel="StyleSheet" href="{$backPath}css/default.css" type="text/css"/>
				<script src="{$backPath}scripts/ContentPageResource.js" type="text/javascript" language="JavaScript"></script>
				<script src="{$backPath}scripts/ContentPageSection.js" type="text/javascript" language="JavaScript"></script>
				<script src="{$backPath}scripts/ContentPageSubSection.js" type="text/javascript" language="JavaScript"></script>
				<script src="{$backPath}scripts/ActivityTreeTable.js" type="text/javascript" language="JavaScript"></script>
				<script src="{$backPath}scripts/ProcessElementPage.js" type="text/javascript" language="JavaScript"></script>
				<script src="{$backPath}scripts/ContentPageToolbar.js" type="text/javascript" language="JavaScript"></script>
				<script src="{$backPath}scripts/contentPage.js" type="text/javascript" language="JavaScript"></script>
				<script src="{$backPath}scripts/processElementData.js" type="text/javascript" language="JavaScript"></script>
				<script type="text/javascript" language="JavaScript">
					var defaultQueryStr = '<xsl:value-of select="$queryString"/>';
					var backPath = '<xsl:value-of select="$backPath"/>';
					var imgPath = '<xsl:value-of select="$imagePath"/>';
					var nodeInfo=null;
					contentPage.preload(imgPath, backPath, nodeInfo,  defaultQueryStr, false, true, true);
				</script>
			</head>
			<body>
			<xsl:if test="$backgroundImage!=''">
				<xsl:attribute name="background"><xsl:value-of select="concat($imagePath, $backgroundImage)"/></xsl:attribute>
			</xsl:if>
			<div id="breadcrumbs"></div>
				<table border="0" cellpadding="0" cellspacing="0" width="100%">
					<tr>
						<td valign="top">
						<div autoWrap="true">
							<xsl:call-template name="overview">
								<xsl:with-param name="elementType" select="$elementType"/>
								<xsl:with-param name="elementTypeName" select="$elementTypeName"/>
								<xsl:with-param name="elementPresentationName" select="$elementPresentationName"/>
								<xsl:with-param name="elementIcon" select="$shapeImage"/>
								<xsl:with-param name="backPath" select="$backPath"/>
								<xsl:with-param name="showTreeBrowser" select="$showTreeBrowser"/>
							</xsl:call-template>
						</div>
							<xsl:call-template name="workflowSection"/>

							<!-- display custom references in the Activity description page -->
							<xsl:call-template name="extendedRefsSectionsAll">
								<xsl:with-param name="elementDown" select="/Element"/>
								<xsl:with-param name="iconLevel" select="'two'"/>
								<xsl:with-param name="layoutLocation" select="''"/>
							</xsl:call-template>
							<!-- display custom RTEs in the Activity description page -->
							<xsl:call-template name="extendedRtesSectionsAll">
								<xsl:with-param name="descriptionDown" select="/Element/reference[@name='presentation']/Element"/>
								<xsl:with-param name="layoutLocation" select="''"/>
							</xsl:call-template>
							
							<!--<xsl:call-template name="activityTabs"/> -->
							
													
							<xsl:call-template name="generalTextFieldSection">
							<!--	<xsl:with-param name="fieldLabel" select="$purposeText"/> -->
								<xsl:with-param name="fieldText" select="$contentDescription/attribute[@name='purpose']"/>
							</xsl:call-template>
							<xsl:call-template name="generalTextFieldSection">
							<!--	<xsl:with-param name="fieldLabel" select="$descriptionText"/> -->
								<xsl:with-param name="fieldText" select="$contentDescription/attribute[@name='mainDescription']"/>
							</xsl:call-template>
							 
							<xsl:call-template name="IllustrationsSection"/>
							<xsl:call-template name="generalTextFieldSection">
								<xsl:with-param name="fieldLabel" select="$staffingText"/>
								<xsl:with-param name="fieldText" select="$contentDescription/attribute[@name='howtoStaff']"/>
							</xsl:call-template>
							
							
							<xsl:call-template name="usageSection">
								<xsl:with-param name="contentDescription" select="$contentDescription"/>
							</xsl:call-template> 
							
							<xsl:call-template name="generalTextFieldSection">
								<xsl:with-param name="fieldLabel" select="$keyConsiderationsText"/>
								<xsl:with-param name="fieldText" select="$contentDescription/attribute[@name='keyConsiderations']"/>
							</xsl:call-template>
							<xsl:call-template name="generalTextFieldSection">
								<xsl:with-param name="fieldLabel" select="$alternativesText"/>
								<xsl:with-param name="fieldText" select="$contentDescription/attribute[@name='alternatives']"/>
							</xsl:call-template>
							
							<xsl:call-template name="moreInfoSection">
								<xsl:with-param name="contentDescription" select="$contentDescription"/>
							</xsl:call-template>
							
							
							
							
							<xsl:call-template name="wbsSection">
								<xsl:with-param name="showFullMethodContent" select="$showFullMethodContent"/>
							</xsl:call-template>
							<xsl:call-template name="copyright">
								<xsl:with-param name="copyright" select="$copyright"/>
							</xsl:call-template>
						</td>
					</tr>
				</table>
			</body>
			<script language="JavaScript" type="text/javascript">
				contentPage.onload();
			</script>
		</html>
	</xsl:template>

	<xsl:template name="activityTabs">
		<xsl:variable name="imagePath" select="concat(/Element/@BackPath, 'images/')"/>
		<table width="100%" border="0" cellspacing="0" cellpadding="0">
			<tr valign="middle">
			
				<td nowrap="nowrap" class="activeTab">
					<span style="white-space:nowrap;">
						<xsl:value-of select="$wbsText"/>
					</span>
				</td>
			</tr>	
		</table>
	</xsl:template>
        
	<xsl:template name="generalTextFieldSection">
		<xsl:param name="fieldLabel"/>
		<xsl:param name="fieldText"/>
		<xsl:if test="$fieldText != ''">
			<div class="sectionHeading">
				<xsl:value-of select="$fieldLabel"/>
			</div>
			<div class="sectionContent">
				<table class="sectionTable" border="0" cellspacing="0" cellpadding="0">
					<tr valign="top">
						<td class="sectionTableSingleCell">
							<xsl:value-of disable-output-escaping="yes" select="$fieldText"/>
						</td>
					</tr>
				</table>
			</div>
		</xsl:if>
	</xsl:template>

	<xsl:template name="IllustrationsSection">
		<xsl:if test="count(referenceList[@name='roadmaps']/Element) + count(referenceList[@name='examples']/Element) > 0">
			<div class="sectionHeading">
				<xsl:value-of select="$illustrationsText"/>
			</div>
			<div class="sectionContent">
				<table class="sectionTable" border="0" cellspacing="0" cellpadding="0">
					<xsl:call-template name="addReferences">
						<xsl:with-param name="refName" select="$roadmapText"/>
						<xsl:with-param name="refElement" select="referenceList[@name='roadmaps']/Element"/>
					</xsl:call-template>
					<xsl:call-template name="addReferences">
						<xsl:with-param name="refName" select="$examplesText"/>
						<xsl:with-param name="refElement" select="referenceList[@name='examples']/Element"/>
					</xsl:call-template>
				</table>
			</div>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="usageSection">
		<xsl:param name="contentDescription"/>
		<xsl:if test="$contentDescription/attribute[@name='usageGuidance'] != '' or $contentDescription/attribute[@name='usageNotes'] != ''">
			<div class="sectionHeading">
				<xsl:value-of select="$usageText"/>
			</div>
			<div class="sectionContent">
				<table class="sectionTable" border="0" cellspacing="0" cellpadding="0">
					<xsl:call-template name="property">
						<xsl:with-param name="fieldLabel" select="$usageGuidanceText"/>
						<xsl:with-param name="fieldText" select="$contentDescription/attribute[@name='usageGuidance']"/>
					</xsl:call-template>
					<xsl:call-template name="property">
						<xsl:with-param name="fieldLabel" select="$usageNotesText"/>
						<xsl:with-param name="fieldText" select="$contentDescription/attribute[@name='usageNotes']"/>
					</xsl:call-template>
				</table>
			</div>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="moreInfoSection">
		<xsl:param name="contentDescription"/>
		<xsl:if test="count(referenceList[@name='toolmentor']/Element) + count(referenceList[@name='concepts']/Element) + count(referenceList[@name='checklists']/Element) + count(referenceList[@name='communicationsMaterials']/Element) + count(referenceList[@name='guidelines']/Element) + count(referenceList[@name='supportingMaterials']/Element) + count(referenceList[@name='reusableAssets']/Element) > 0">
			<div class="sectionHeading">
				<xsl:value-of select="$moreInfoText"/>
			</div>
			<div class="sectionContent">
				<table class="sectionTable" border="0" cellspacing="0" cellpadding="0">
					<xsl:call-template name="addChecklists">
						<xsl:with-param name="checklists" select="referenceList[@name='checklists']/Element"/>
					</xsl:call-template>
					<xsl:if test="referenceList[@name='communicationsMaterials']">
						<xsl:call-template name="addReferences">
							<xsl:with-param name="refName" select="$communicationsMaterialsText"/>
							<xsl:with-param name="refElement" select="referenceList[@name='communicationsMaterials']/Element"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="referenceList[@name='educationMaterials']">
						<xsl:call-template name="addReferences">
							<xsl:with-param name="refName" select="$educationMaterialsText"/>
							<xsl:with-param name="refElement" select="referenceList[@name='educationMaterials']/Element"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:call-template name="addGuidelines">
						<xsl:with-param name="guidelines" select="referenceList[@name='guidelines']/Element"/>
					</xsl:call-template>
					<xsl:call-template name="addConcepts">
						<xsl:with-param name="concepts" select="referenceList/Element[@Type='Concept']"/>
					</xsl:call-template>
					<xsl:call-template name="addToolMentors">
						<xsl:with-param name="toolMentors" select="referenceList/Element[@Type='ToolMentor']"/>
					</xsl:call-template>
					<xsl:call-template name="addReusableAssets">
						<xsl:with-param name="reusableAssets" select="referenceList[@name='reusableAssets']/Element"/>
					</xsl:call-template>
					<xsl:call-template name="addReferences">
						<xsl:with-param name="refName" select="$supportingMaterialsText"/>
						<xsl:with-param name="refElement" select="referenceList[@name='supportingMaterials']/Element"/>
					</xsl:call-template>
					<xsl:call-template name="addWhitePapers">
						<xsl:with-param name="whitePapers" select="referenceList/Element[@Type='Whitepaper']"/>
					</xsl:call-template>
				</table>
			</div>
		</xsl:if>
	</xsl:template>
        
	<xsl:template name="workflowSection">
		<xsl:if test="diagrams/diagram[@name='Activity'] or diagrams/diagram[@name='ActivityDetail'] or diagrams/userdiagram[@name='Activity'] or diagrams/userdiagram[@name='ActivityDetail']">
		<!--	<div class="sectionHeading">
				<xsl:value-of select="$workflowText"/>
			</div>-->
			<div class="sectionContent">
				<table class="sectionTable" border="0" cellspacing="0" cellpadding="0">
					<xsl:choose>
						<xsl:when test="diagrams/userdiagram[@name='Activity']">
							<tr>
								<td class="sectionTableSingleCell" colspan="2" align="left">
									<xsl:value-of disable-output-escaping="yes" select="diagrams/userdiagram[@name='Activity']"/>
								</td>
							</tr>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="diagrams/diagram[@name='Activity']">
								<tr>
									<td class="sectionTableSingleCell" colspan="2" align="left">
										<xsl:call-template name="displayDiagram">
											<xsl:with-param name="diagram" select="diagrams/diagram[@name='Activity']"/>
										</xsl:call-template>
									</td>
								</tr>
							</xsl:if>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:choose>
						<xsl:when test="diagrams/userdiagram[@name='ActivityDetail']">
							<tr>
								<td class="sectionTableSingleCell" colspan="2" align="left">
									<xsl:value-of disable-output-escaping="yes" select="diagrams/userdiagram[@name='ActivityDetail']"/>
								</td>
							</tr>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="diagrams/diagram[@name='ActivityDetail']">
								<tr>
									<td class="sectionTableSingleCell" colspan="2" align="left">
										<xsl:call-template name="displayDiagram">
											<xsl:with-param name="diagram" select="diagrams/diagram[@name='ActivityDetail']"/>
										</xsl:call-template>
									</td>
								</tr>
							</xsl:if>
						</xsl:otherwise>
					</xsl:choose>
				</table>
			</div>
		</xsl:if>
	</xsl:template>

	<xsl:template name="wbsSection">
		<xsl:param name="showFullMethodContent"/>
		<xsl:variable name="imagePath" select="concat(/Element/@BackPath, 'images/')"/>
		<xsl:variable name="colSize" select="count(breakdown[@name='Work Breakdown Structure']/columns/column)"/>
		<xsl:variable name="presentationName" select="breakdown[@name='Work Breakdown Structure']/columns/column[@id='presentation_name']"/>
		<xsl:variable name="isPlanned" select="breakdown[@name='Work Breakdown Structure']/columns/column[@id='is_planned']"/>
		
	<!--	<div class="sectionHeading">
			<xsl:value-of select="$workBreakdownText"/>
		</div>
	-->	<div class="sectionContent">
		<div id="treeContent" align="left"></div>
<script language="JavaScript">
contentPage.processPage.treeTable.data = {
title: "<xsl:value-of select="$workBreakdownText"/>", summary: "<xsl:value-of select="$workBreakdownText"/>", 
      columns: [
      		 ["<xsl:value-of select="$presentationName/@id"/>", "<xsl:value-of select="$presentationName/@label"/>"]
             <xsl:if test="$isPlanned">
             	,["<xsl:value-of select="$isPlanned/@id"/>", "<xsl:value-of select="$isPlanned/@label"/>"]
             </xsl:if>
	       ],
       
       rows: [<xsl:for-each select="breakdown[@name='Work Breakdown Structure']/Element">
						<xsl:call-template name="wbsItem">
							<xsl:with-param name="element" select="."/>
							<xsl:with-param name="indent" select="0"/>
							<xsl:with-param name="parentNodeId" select=" '' "/>
							<xsl:with-param name="showFullMethodContent" select="$showFullMethodContent"/>
						</xsl:call-template>
					</xsl:for-each>
]};
				</script>
	
		</div>
	</xsl:template>

	<!-- write the wbs tr html -->
	<!-- init(id, parentId, relPath, isSupressed, indentSize, hasChildren, index, prefix, title, url, steps, predecessors, info, repeatable, multiOccurences, optional, planned, type) -->
	<xsl:template name="wbsItem">
		<xsl:param name="element"/>
		<xsl:param name="parentNodeId"/>
		<xsl:param name="indent"/>
		<xsl:param name="showFullMethodContent"/>		
		<xsl:variable name="elementType" select="$element/@Type"/>
		<xsl:variable name="imagePath" select="concat(/Element/@BackPath, 'images/')"/>
		<xsl:variable name="hasChildren">
			<xsl:choose>
				<xsl:when test="count($element/Element) > 0">true</xsl:when>
				<xsl:otherwise>false</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="typeName">
			<xsl:choose>
				<xsl:when test="$showFullMethodContent = 'true'">
					<xsl:choose>										
						<xsl:when test="$elementType = 'TaskDescriptor'">
							<xsl:value-of select="$taskText"/>
						</xsl:when>
						<xsl:when test="$elementType = 'RoleDescriptor'">
							<xsl:value-of select="$roleText"/>
						</xsl:when>
						<xsl:when test="$elementType = 'WorkProductDescriptor'">
							<xsl:value-of select="$workProductText"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$element/@TypeName"/>
						</xsl:otherwise>
					</xsl:choose>									
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$element/@TypeName"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
{
	id: "<xsl:value-of select="$element/@nodeId"/>",
	parentId: "<xsl:value-of select="$parentNodeId"/>",
	relPath: "<xsl:value-of select="$element/@relProcessPath"/>",
	isSuppressed: "<xsl:value-of select="$element/@isSupressed"/>",
	indentSize: <xsl:value-of select="$indent"/>,
	hasChildren:<xsl:value-of select="$hasChildren"/>,
	index: "<xsl:value-of select="$element/@Index"/>",
	prefix: "<xsl:value-of select="$element/attribute[@name='prefix']"/>",
	name: "<xsl:value-of select="$element/@Name"/>",
	title: "<xsl:value-of select="$element/@DisplayName"/>",
	url: "<xsl:value-of select="concat(/Element/@BackPath, $element/@Url)"/>", 
	predecessors: "<xsl:value-of select="$element/@Predecessors"/>",
	info: "<xsl:value-of select="$element/@ModelInfo"/>",
	type: "<xsl:value-of select="$typeName"/>", 
	repeatable: "<xsl:value-of select="$element/attribute[@name='isRepeatable']"/>",
	multiOccurences: "<xsl:value-of select="$element/attribute[@name='hasMultipleOccurrences']"/>",
	optional: "<xsl:value-of select="$element/attribute[@name='isOptional']"/>",
	planned: "<xsl:value-of select="$element/attribute[@name='isPlanned']"/>",
	ongoing: "<xsl:value-of select="$element/attribute[@name='isOngoing']"/>",
	eventDriven: "<xsl:value-of select="$element/attribute[@name='isEventDriven']"/>", 
	team: "<xsl:value-of select="$element/@Team"/>",
	entryState: "", exitState: "", deliverable: "",
	variabilityType: "<xsl:value-of select="$element/attribute[@name='variabilityType']"/>",
	steps: [
	<xsl:variable name="stepSize"><xsl:value-of select="count($element/Steps/Step)"/>
	</xsl:variable>
	<xsl:for-each select="$element/Steps/Step"><xsl:value-of select="@selected"/>
	<xsl:if test="position() != $stepSize">,
	</xsl:if>
	</xsl:for-each>]
},
<xsl:if test="count($element/Element) > 0">
			<xsl:for-each select="$element/Element">
				<xsl:call-template name="wbsItem">
					<xsl:with-param name="element" select="."/>
					<xsl:with-param name="indent" select="$indent+1"/>
					<xsl:with-param name="parentNodeId" select="$element/@nodeId"/>
					<xsl:with-param name="showFullMethodContent" select="$showFullMethodContent"/>					
				</xsl:call-template>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>
